@@ -2,7 +2,7 @@
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>",
-  eval = identical(Sys.getenv("TORCH_TEST", unset = 0), 1)
+  eval = identical(Sys.getenv("TORCH_TEST", unset = "0"), "1")
 )
 
 ## ----setup--------------------------------------------------------------------
